Examples & Tutorials
====================

You can download and play with these notebooks to get a feeling for how ``noctiluca`` and its data structures work. If you don't want to run them yourself, you can also consult the [examples page](https://noctiluca.readthedocs.io/en/latest/examples.html) of the documentation.

For developers
--------------
When writing example notebooks, make sure to remove the output cells before adding them to the repo. This ensures good readability of diffs!
